import { devUrl, successCode } from '../config/constants';
import { IMyApp } from '../app';
const app = getApp<IMyApp>();

const fetch = (req: wx.RequestOption) =>
  new Promise((resolve, reject) => {
    const token = app.globalData.token;
    wx.request({
      ...req,
      header: token
        ? {
            token,
            ...req.header,
          }
        : req.header,

      success: resolve,
      fail: reject,
    });
  }).then((res: wx.RequestSuccessCallbackResult) => {
    const { code, ...otherkeys } = res.data;
    if (code === successCode) {
      return otherkeys;
    } else {
      throw {
        errMsg: res.data.msg || '网络异常',
      };
    }
  });

export const systemFetch = (req: wx.RequestOption) =>
  fetch({ ...req, url: devUrl.SYSTEM_SERVER_URL + req.url });
export const statisticsFetch = (req: wx.RequestOption) =>
  fetch({ ...req, url: devUrl.STATISTICS_SERVER_URL + req.url });

export default fetch;
